"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseDatabaseService = void 0;
class BaseDatabaseService {
    tableName;
    pkName;
    expressionBuilder;
    queryExecutor;
    constructor(tableName, pkName = "id", expressionBuilder, queryExecutor) {
        this.tableName = tableName;
        this.pkName = pkName;
        this.expressionBuilder = expressionBuilder;
        this.queryExecutor = queryExecutor;
    }
    async fetchWithFiltersAndPagination(query, client) {
        try {
            const { params, limit, offset, page, pagination } = await this.prepareQueryParameters(query);
            const items = await this.queryExecutor.executeQuery(params, client);
            const total = items.length;
            const data = this.processResults(items, limit, offset, pagination);
            return {
                data,
                total,
                page,
                limit
            };
        }
        catch (error) {
            this.handleError(error);
            throw error;
        }
    }
    calculatePaginationValues(pagination) {
        let { page = 1, limit = 100, offset } = pagination;
        page = Math.max(1, Math.floor(page));
        limit = Math.max(0, Math.floor(limit));
        if (typeof offset !== "number" || offset < 0) {
            offset = (page - 1) * limit;
        }
        return { limit, offset, page };
    }
}
exports.BaseDatabaseService = BaseDatabaseService;
//# sourceMappingURL=BaseDatabaseService.js.map